/* Last modified: August 19, 2015

*--------------------*
*    INPUT FILES     *
*--------------------*

Packages needed: none
Do-files called: none

Files needed: 

mw_state_daily.dta - Minimum wage values by state by date, 1975-2012
dollars2011_cpiu_monthly.dta - Monthly CPI deflator (prepared by data prep code)

*/

*--------------------*
* Set these:

global datadir "/home/jeremy/data/jhr/data_code" // Location of data and code
global savedir "/home/jeremy/data/jhr/tex" // Location of figures and tables folders

*--------------------*

clear all
set more off
cd "$datadir"

*----------------------*
*  APPENDIX FIGURES    *
*----------------------*

use mw_state_daily , clear
gen month = month(date)
order month, after(year)
keep if day(date) == 1 // 1st of each month
merge m:1 year month using dollars2011_cpiu_monthly
keep if _merge == 3
drop if statefips == 0
sort statefips year month
gen realmw = mw * dol2011
gen realfedmw = fedmw * dol2011
drop _merge date dol2011
save mw_state_monthly , replace

* Figures on historical minimum wages and super-federal MW counts

use mw_state_monthly , clear

keep if month == 1 // Using January minimum wage values

keep mw fedmw statefips year

gen sf = 0
replace sf = 1 if mw > fedmw

egen superfed = sum (sf) , by(year)

gen temp = mw if sf == 1
egen avgwage = mean(temp) , by(year)

keep avgwage fedmw superfed year

duplicates drop
duplicates drop year , force // Should drop zero
sort year

label define mw_dollars 3 "$3.00" 6 "$6.00" 9 "$9.00"
label values fedmw mw_dollars

#delimit ;
twoway line fedmw avgwage year, yaxis(1) color(black black) lpattern(solid longdash) 
ylabel(3 6 9 , valuelabels) || bar superfed year, barw(.5) yaxis(2) color(gs12) ||
in 1/38 
, ysca(axis(1) r(-2 10))
  ysca(axis(2) r(  0   70))
  ylabel(0(10)30, axis(2))
ytitle("                    Nominal Minimum Wage", margin(r+2.0))
ytitle(" Number of states", axis(2) bexpand just(left) margin(l+1.0))
xtitle("")
xlabel(1980(10)2010)
legend(rows(3) order(2 "Average super-federal state nominal minimum wage" 1 "Federal nominal minimum wage" ///
3 "Number of states mandating super-federal minimum wage") )
graphregion(color(white))
;
#delimit cr

graph export "$savedir/figures/FigA4-1-countsuperfederal.png" , replace width(2000)


* Figure : real minimum wages

use mw_state_monthly , clear

keep if month == 1 // Using January minimum wage valuese

keep realmw realfedmw statefips year

gen sf = 0
replace sf = 1 if realmw > realfedmw

egen superfed = sum (sf) , by(year)

gen temp = realmw if sf == 1
egen avgwage = mean(temp) , by(year)

keep avgwage realfedmw superfed year

duplicates drop
duplicates drop year , force // Should drop zero
sort year

label define mw_dollars 3 "$3.00" 6 "$6.00" 9 "$9.00"
label values realfedmw mw_dollars

#delimit ;

twoway
line realfedmw avgwage year, yaxis(1) color(black black) lpattern(solid longdash) ylabel(3 6 9 ,valuelabels) ||
bar superfed year, barw(.5) yaxis(2) color(gs12) ||
in 1/38
, ysca(axis(1) r(-2 10))
  ysca(axis(2) r(  0   70))
  ylabel(0(10)30, axis(2))
ytitle("                    Real Minimum Wage", margin(r+2.0))
ytitle(" Number of states", axis(2) bexpand just(left) margin(l+1.0))
xtitle("")
xlabel(1980(10)2010)
legend(rows(3) order(2 "Average super-federal state real minimum wage ($2011)" 1 "Federal real minimum wage ($2011)" ///
3 "Number of states mandating super-federal minimum wage") )
graphregion(color(white))
;
#delimit cr

graph export "$savedir/figures/FigA4-2-countsuperfederal_real.png", replace width(2000)
window manage close graph


*------------------*
*   MW RESIDUALS   *
*------------------*

* Figure : Standard deviation of MW residuals to state and quarterly fixed effects

use mw_state_monthly , clear
gen monthly = ym(year, month)
xtset statefips monthly
qui areg realmw i.statefips , absorb(monthly)
predict xb , xb
gen resmw = realmw - xb

gen fedchg = ( (fedmw - l.fedmw > 0) & (fedmw - l.fedmw != .) )

egen meanres = mean(resmw) , by(monthly)
egen sdmw = sd(resmw) , by(monthly)

label define monthly 240 "1980" 360 "1990" 491 "2000" 600 "2010"
label values monthly monthly

keep monthly sdmw fedchg fedmw meanres
duplicates drop
sort monthly

#delimit ;
line sdmw monthly , lcolor(black) lwidth(0.6)
graphregion(color(white))
xtitle("") ytitle("Standard deviation of MW residuals (dollars 2011)" , margin(r+2.0))
note("Minimum wage residuals to state and monthly fixed effects. Vertical lines indicate Federal changes.")
xlabel(240 360 491 600, valuelabels )
ylabel(0(0.2)1)
xline(192 , lcolor(gs12) lpattern(dash) ) 
xline(216 , lcolor(gs12) lpattern(dash) ) 
xline(228 , lcolor(gs12) lpattern(dash) ) 
xline(240 , lcolor(gs12) lpattern(dash) ) 
xline(252 , lcolor(gs12) lpattern(dash) ) 
xline(363 , lcolor(gs12) lpattern(dash) ) 
xline(375 , lcolor(gs12) lpattern(dash) )
xline(441 , lcolor(gs12) lpattern(dash) ) 
xline(452 , lcolor(gs12) lpattern(dash) ) 
xline(571 , lcolor(gs12) lpattern(dash) ) 
xline(583 , lcolor(gs12) lpattern(dash) ) 
xline(595 , lcolor(gs12) lpattern(dash) )
;
#delimit cr

graph export "$savedir/figures/FigA4-3-stddev-MW-residuals.png" , width(2000) replace
window manage close graph


********

* Figures on MW erosion

use mw_state_monthly , clear

gen mwincr = (mw > mw[_n-1] & realmw > realmw[_n-1] & state == state[_n-1] )
gen mwdiff = realmw - realmw[_n-1]

gen incdiff = mwdiff if mwincr == 1
gen afterdiff = incdiff[_n-1] + mwdiff if mwinc[_n-1] == 1 & mwinc != 1
replace afterdiff = afterdiff[_n-1] + mwdiff if mwinc != 1 & afterdiff[_n-1] != . & state == state[_n-1]

gen zeroed = (afterdiff <= 0 & afterdiff[_n-1] > 0)

gen counter = 0 if mwinc == 1
replace counter = counter[_n-1] + 1 if counter == . & counter[_n-1] != .
replace counter = . if zeroed == 0

* time until next MW change:

gen changed = 0 if counter != .
replace changed = changed[_n-1] + 1 if changed == . & changed[_n-1] != .
replace changed = . if changed[_n+1] != 0


* Figure : Distribution of real minimum wage increases

su incdiff , d // To determine statistics reported in figure note
* Note: This is 1976 - 2012

#delimit ;
hist incdiff , freq width(0.1) graphregion(color(white)) xline(0.55, lcolor(black))
xline(0.55,lcolor(black) lpattern(dash)) bcolor(gs12)
xtitle("Real increase in MW (dollars 2011)") 
note("Bin size: 10 cents. Median: 55 cents and mean: 55 cents. 678 MW increases from 1976-2012")
;
#delimit cr

graph export "$savedir/figures/FigA4-4-MW-real-dollar-changes.png" , width(2000) replace


* Figure : Cumulative difference in real minimum wage prior to a new increase

su afterdiff if incdiff[_n+1] != . , d  // To determine statistics reported in figure note

#delimit ;
hist afterdiff if mwinc[_n+1]==1, freq width(0.1) graphregion(color(white)) xline(-0.12, lcolor(black))
xline(-0.11, lcolor(black) lpattern(dash)) bcolor(gs12)
xtitle("Remaining cumulative real increase in MW (dollars 2011)") 
note("Bin size: 10 cents. Median: -12 cents and mean: -11 cents. 626 MW increases from 1976-2012")
;
#delimit cr

graph export "$savedir/figures/FigA4-5-MW-real-dollar-remaining-cumulative-changes.png" , width(2000) replace


* Figure : Erosion of real increases in minimum wage

su counter , d // To determine statistics reported in figure note

#delimit ;
hist counter , freq width(1) xlabel(0(12)84) xline(16, lcolor(black)) xline(22, lcolor(black) lpattern(dash))
graphregion(color(white)) bcolor(gs12)
xtitle("Months following nominal increase until cumulative change in real MW is zero")
note("Bin size: 1 month. Median: 16 and mean: 22 months. 419 of 678 MW changes during 1976-2012")
;
#delimit cr

graph export "$savedir/figures/FigA4-6-MW-erosion-months-counter.png" , width(2000) replace

window manage close graph


/* RELATIVE increases in Census Region */

use mw_state_monthly , clear

gen mwincr = (mw > mw[_n-1] & realmw > realmw[_n-1] & state == state[_n-1] )
gen mwdiff = realmw - realmw[_n-1]

egen cenregct = count(censusreg) , by(censusreg year month)

egen smwdiff = sum(mwdiff) , by(censusreg year month)
gen lomwdiff = smwdiff - mwdiff
gen lomm = lomwdiff / cenregct

drop smwdiff lomwdiff

gen relchg = mwdiff - lomm

gen relchg1 = relchg if mwincr == 1
gen cumchg = relchg1 if mwinc == 1
replace cumchg = cumchg[_n-1]+relchg if cumchg[_n-1] != . & cumchg == . & state == state[_n-1]

gen relinc = 0 if mwinc == 1
replace relinc = 1 if mwinc == 1 & relchg > 0

* Figure : Distribution of relative minimum wage increases

su cumchg if relinc == 1 , d // To determine statistics reported in figure note

#delimit ;
hist cumchg if relinc == 1 , freq width(0.1) graphregion(color(white)) xline(0.13,lcolor(black))
xline(0.25,lcolor(black) lpattern(dash)) bcolor(gs12)
xtitle("Real increase in MW (dollars 2011) relative to Region") 
note("Bin size: 10 cents. Median: 13 cents and mean: 25 cents. 646 MW increases from 1976-2012") 
;
#delimit cr

graph export "$savedir/figures/FigA4-7-relative-MW-real-dollar-changes.png" , width(2000) replace

* Figure : Cumulative difference in relative minimum wage prior to a new increase

su cumchg if relinc[_n+1] == 1 , d // To determine statistics reported in figure note

#delimit ;
hist cumchg if relinc[_n+1] == 1 , freq width(0.1) graphregion(color(white)) xline(0.02,lcolor(black))
xline(-0.01,lcolor(black) lpattern(dash)) bcolor(gs12)
xtitle("Remaining cumulative real increase in MW (dollars 2011) relative to Region") 
note("Bin size: 10 cents. Median: 2 cents and mean: -1 cent. 597 MW increases from 1976-2012") 
;
#delimit cr

graph export "$savedir/figures/FigA4-8-relative-MW-real-dollar-remaining-cumulative-changes.png" , width(2000) replace

gen zeroed = (cumchg <=0 & cumchg[_n-1] > 0)
gen counter = 0 if relinc == 1
replace counter = counter[_n-1]+1 if counter==. & counter[_n-1]!=. & state == state[_n-1]
replace counter = . if zeroed == 0

* Figure : Erosion of relative increases in minimum wage

su counter , d // To determine statistics reported in figure note

#delimit ;
hist counter , freq width(1) xlabel(0(12)84) xline(12,lcolor(black)) xline(17,lcolor(black) lpattern(dash))
graphregion(color(white)) bcolor(gs12) 
xtitle("Months until cumulative change in real MW is zero relative to Region")
note("Bin size: 1 month. Median: 12 and mean: 17 months. 282 of 597 MW changes during 1976-2012")
;
#delimit cr

graph export "$savedir/figures/FigA4-9-relative-MW-erosion-months-counter.png" , width(2000) replace

window manage close graph

/* */

clear all
